StockOrderController class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • StockOrderController
Implemented types

Constructors

StockOrderController()

Properties

actionType ↔ RxString
getter/setter pair
bankName String
getter/setter pair
bankNameList ↔ RxList<String>
getter/setter pair
bankNames List<PaymentData>
getter/setter pair
branchNameList ↔ RxList<String>
getter/setter pair
branchNames List<PaymentData>
getter/setter pair
builderController TextEditingController
getter/setter pair
cacheCartId ↔ RxString
getter/setter pair
cancelList ↔ RxList<Content>
getter/setter pair
cancelOrderController TextEditingController
getter/setter pair
cart_id ↔ RxString
getter/setter pair
cashhName String
getter/setter pair
categories List<CategoryList>
getter/setter pair
categoryList ↔ RxList<CategoryList>
getter/setter pair
checkinId String
getter/setter pair
communeController TextEditingController
getter/setter pair
createReOrder ↔ RxInt
getter/setter pair
currentAddress ↔ Rx<Address>
getter/setter pair
currentDeliveryLocation ↔ LatLng
getter/setter pair
currentDeliveryLocationAtPickup ↔ LatLng
getter/setter pair
currentSeletedAddress List
getter/setter pair
currentState ↔ RxString
getter/setter pair
customerID ↔ RxString
getter/setter pair
dealerGrade ↔ RxString
getter/setter pair
dealerId int
getter/setter pair
deliveryList ↔ RxList<ShippingMethodTypes>
getter/setter pair
deliveryMangamentnList ↔ RxList<DeliveryContent>
getter/setter pair
deliverySelected ↔ Rx<DeliveryAddressModel>
getter/setter pair
deliveryShippingSelected ↔ RxString
getter/setter pair
dio → Dio
final
discount_id ↔ RxString
getter/setter pair
discountAmount ↔ RxString
getter/setter pair
discountId ↔ RxString
getter/setter pair
discountList ↔ RxList<CartDiscountsList>
getter/setter pair
distributerLevelId int
getter/setter pair
districtController TextEditingController
getter/setter pair
expressTimeSelect ↔ RxString
getter/setter pair
firstName ↔ RxString
getter/setter pair
freeItemList List<ContentModel>
getter/setter pair
freeItems List<ContentModel>
getter/setter pair
fromDateController → Rx<TextEditingController>
final
getInProgressHistoryList ↔ RxList<SellInOrderHistory>
getter/setter pair
getSearchedList ↔ RxList<SellInOrderHistory>
getter/setter pair
getStockHistoryList ↔ RxList<SellInOrderHistory>
getter/setter pair
grnTransactionList ↔ RxList<Content>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
houseNoController TextEditingController
getter/setter pair
houseNoKhmrController TextEditingController
getter/setter pair
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
invoice InvoiceOrderStockResponse
getter/setter pair
isAllDataFetched ↔ RxBool
getter/setter pair
getter/setter pair
isButtonEnabled ↔ RxBool
getter/setter pair
isCancelOrderSelected ↔ RxString
getter/setter pair
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isDateSelected ↔ RxBool
getter/setter pair
isDealerFlow bool
getter/setter pair
isDeliveryAvailable ↔ RxBool
isDeliveryAvailable is used to check if delivery is available for the selected location and is used to show/hide configurable message.
getter/setter pair
isDeliveryMethodSelected ↔ RxBool
getter/setter pair
isDeliverySelected ↔ RxBool
getter/setter pair
isDiscardPayment bool
getter/setter pair
isInProgressReceived ↔ RxBool
getter/setter pair
isLoadingMore ↔ RxBool
getter/setter pair
isOrderCancelled ↔ RxBool
getter/setter pair
isPaymentSelected ↔ RxBool
getter/setter pair
isPaymentSelectName ↔ RxString
getter/setter pair
isPickupMethodSelected ↔ RxBool
getter/setter pair
isPickupSelected ↔ RxString
getter/setter pair
isResponseReceived ↔ RxBool
getter/setter pair
isSearchAllDataFetched ↔ RxBool
getter/setter pair
isSearchingOrder ↔ RxBool
getter/setter pair
isSearchingPickupLocation ↔ RxBool
getter/setter pair
isSearchResponseReceived ↔ RxBool
getter/setter pair
isShippingMethodSelected ↔ RxBool
isShippingMethodSelected is used to check if the shipping method is selected
getter/setter pair
isWalletSelected ↔ RxBool
getter/setter pair
isWingPaymentAvailable ↔ RxBool
getter/setter pair
lastName ↔ RxString
getter/setter pair
lat ↔ RxDouble
getter/setter pair
listeners int
no setterinherited
localization Localization
final
long ↔ RxDouble
getter/setter pair
mywalletbalance ↔ RxDouble
getter/setter pair
mywalletbalanceUndo ↔ RxDouble
getter/setter pair
nextVisitDate String
getter/setter pair
noteController TextEditingController
getter/setter pair
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onFilter → RxBool
final
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
onStatusFilter → RxBool
final
getter/setter pair
parentId String
getter/setter pair
partnerId String
getter/setter pair
partnerName String
getter/setter pair
paymentBankDataList List<PaymentData>
getter/setter pair
paymentCreateTransactionId ↔ RxString
getter/setter pair
paymentDataList List<PaymentData>
getter/setter pair
paymentMethods List<PaymentMethodModel>
getter/setter pair
paymentModeList ↔ RxList<PaymentData>
getter/setter pair
paymentModes List<PaymentData>
getter/setter pair
paymentModesRecieved ↔ RxList<PaymentCollectionByModeList>
getter/setter pair
paymentmodestatus int
getter/setter pair
paymentModeValidateList ↔ RxList<Mode>
getter/setter pair
paymentModeValidateResponse Map<String, Object?>
getter/setter pair
paymentPendingCases List<String>
getter/setter pair
paymentScreenTime int
getter/setter pair
paymentScreenType ↔ RxString
getter/setter pair
paymentStatus ↔ RxString
getter/setter pair
paymentStatusApiCall int
getter/setter pair
paymentStatusList String
getter/setter pair
paymentStatusName String
getter/setter pair
paymentTransactionId ↔ RxString
getter/setter pair
phone ↔ RxString
getter/setter pair
pickupLocationList ↔ Rx<PickupLocationModel>
getter/setter pair
pickupLocationListContent ↔ RxList<Content>
getter/setter pair
pickupPointList List<DeliveryAddressModel>
getter/setter pair
pickupSelected ↔ Rx<DeliveryAddressModel>
getter/setter pair
pickupSelectedAddress ↔ Rx<Profile>
getter/setter pair
pickUpTimeSelect ↔ RxString
getter/setter pair
productList ↔ RxList<OfferList>
getter/setter pair
products List<OfferList>
getter/setter pair
promotionList List<ContentModel>
getter/setter pair
promotions List<ContentModel>
getter/setter pair
provinceController TextEditingController
getter/setter pair
quantity ↔ RxInt
getter/setter pair
radioCancelOrderSelected ↔ Rx<Content>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchController TextEditingController
getter/setter pair
searchedText ↔ Rx<String>
getter/setter pair
searchPickupController TextEditingController
getter/setter pair
selectedDeliveryAddress ↔ RxString
getter/setter pair
selectedDeliveryAddressForPickUp ↔ RxString
getter/setter pair
selectedDeliveryId ↔ RxString
getter/setter pair
selectedDeliverylattitude ↔ RxDouble
getter/setter pair
selectedDeliverylongitude ↔ RxDouble
getter/setter pair
selectedDeliveryName ↔ RxString
getter/setter pair
selectedDeliveryNameForPickUp ↔ RxString
getter/setter pair
selectedDeliveryOption ↔ Rx<DeliveryAddressModel>
getter/setter pair
selectedDeliveryOptionType ↔ RxString
getter/setter pair
selectedDeliveryPrice ↔ RxDouble
getter/setter pair
selectedFirstTimeSelect String
getter/setter pair
selectedLocation String
getter/setter pair
selectedLocationType ↔ RxString
getter/setter pair
selectedPaymentMethod ↔ Rx<PaymentData>
getter/setter pair
selectedProduct ↔ RxList<ProductContentModel>
getter/setter pair
selectedScreenLocationType ↔ RxString
getter/setter pair
selectedStatus ↔ RxString
getter/setter pair
sellThruOrder ↔ Rx<SellThruProductDataModel>
getter/setter pair
showGrnButton ↔ RxBool
getter/setter pair
standardTimeSelect ↔ RxString
getter/setter pair
state ↔ RxString
getter/setter pair
stockHistories List<CollectStockHistoryContentModel>
getter/setter pair
stockHistoryList ↔ RxList<CollectStockHistoryContentModel>
getter/setter pair
storage → GetStorage
final
streetNoController TextEditingController
getter/setter pair
streetNoKhmrController TextEditingController
getter/setter pair
subTotal ↔ RxString
getter/setter pair
taxAmount ↔ RxString
getter/setter pair
toDateController → Rx<TextEditingController>
final
toPayAmount ↔ RxDouble
getter/setter pair
totalAmount ↔ RxString
getter/setter pair
totalPickupLocations int
getter/setter pair
totalQuantity ↔ RxString
getter/setter pair
transactionId String
getter/setter pair
validationMessage ↔ RxString
getter/setter pair
validationResults ↔ RxList<ValidationResult>
getter/setter pair

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
addToCart(BuildContext context, AddToCartRequest request, ProductContentModel offerList) → dynamic
addToCartInSellIn(BuildContext context, String cartId, AddToCartSellInRequest request) → dynamic
addToCartReOrder(BuildContext context, AddToCartRequest request, ProductContentModel offerList) → dynamic
bankPayment(BuildContext context, String id, String cartId, String bankName, String branchName, String refNbr, String amount, String date, String accNbr, int receiptId) → dynamic
callDealerDetailsApi(int dealerId, {required bool isDealerFlow}) Future<void>
callDistributerLevelApi(int levelId) Future<void>
callPaymentTransactionCreateApi(String type, String amount) Future<void>
callPaymentTransactionStatusApi(String transaction, bool externalCheckRequried, bool isDiscard, {bool isClickBack = false, bool isFromDeepLink = false, bool isClickPaymentContinue = false}) Future<void>
callPickUpUpdate() Future<void>
cancelProductOrderApi(String cancellationReason, String orderId) Future<void>
cashPayment(BuildContext context, String id, String cartId, String amount, String localCurrencyAmount, {bool isCashOnDelivery = false}) → dynamic
checkAppAvailability() Future<bool>
checkMandatoryFields() → dynamic
clean(BuildContext context, {bool isFromSellin = false}) → dynamic
deleteCart(BuildContext context, String cartId) → dynamic
deleteProduct(BuildContext context, String cartId, String productId) → dynamic
disableCancelButton(String completedStatus) bool
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
forceUpdateShippingMethod() → void
getAddedScannedQty(String? name, TextEditingController controller, {bool isNewCart = false}) int
getAddressString(Address? address) String
getCategories(BuildContext context) → dynamic
getDeliveryManagement({String? search}) Future<void>
getGrnTransationList(String filterExternalReferenceId) → void
getInProgressOrderHistory(BuildContext context, String partnerId, {String? state, String? fromDate, String? toDate, int offset = 0}) → dynamic
getInvoice(String transactionId, String? orderId) Future<void>
getInvoiceDetails(BuildContext context, String invoiceId) → dynamic
getNextVisit(BuildContext context) Future
getPaymentDetails({required String id}) → void
getPaymentModeList() → void
getPaymentModes(BuildContext context) → dynamic
getPaymentModeValidate(String cardId) → dynamic
getPickUpAddressString(Address? address) String
getPickUpLocationList(String dealerId, {String? search, int? page = 1}) Future<void>
getProductId(String? offerId) String
getProducts(BuildContext context, String categoryId) Future<List<OfferList>?>
getProductValues(List<ProductContentModel> productList) → void
getRequestCancelData() → dynamic
getRomProductDetails({required String mainSaleOrderId}) Future<SellInOrderHistory>
getStockHistory(BuildContext context, String? date, String partnerId, {String? state, String? fromDate, String? toDate, int offset = 0, String? orderId, bool isFromEmployee = false, String itemCode = "", String? type, String? dealerId}) → dynamic
goToPaymentPendingSuccessScreen() → void
Navigate to the payment pending success screen This function is called when the payment status is pending or failed and the user is redirected to the success screen with a flag indicating payment failure. We are going to pending screen, even if payment collection or order creation is failed.
grnSubmit(String orderId, String transferOrderId, String id) Future<GrnSubmitModel?>
handleApiResponse(PaymentStatusResponseModel? model) → void
handleBackApiResponse(PaymentStatusResponseModel? model, {bool isClickPaymentContinue = false, bool isClickBack = false}) → void
isPickupOrDelivery() String
launchPaymentGateway(String url, String transactionid, String amount) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
override
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
orderCreation(BuildContext context, String cartId, String paymentId, String transactionType, {required bool isBank, bool isCashOnDelivery = false}) → dynamic
orderPendingApi({required int entityId}) Future<PaymentPendingResponse?>
paymentMethodValidate() Future<void>
prepareSellInCartRequest() → dynamic
printLogs(Dio dio) → dynamic
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
refreshOrderPending(BuildContext context, {required String khqrTransactionId, required String orderId, required Function onStatusChange}) → dynamic
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
removePromotion(BuildContext context, String cartDiscountId, String cartId) → dynamic
searchOrderHistory(BuildContext context, String partnerId, String orderId, {String? state, String? fromDate, String? toDate, int offset = 0, bool isFromEmployee = false, String itemCode = "", String? type, String? currentState}) Future<void>
setDeliveryLatLng({required LatLng loc}) → void
showDialogForPaymentAlert() Future<void>
Payment Dialog Alert
showPaymentFailedAlert() Future<void>
showPendingOrderAlert({String? msgLabel}) Future<void>
startApiPolling(String transaction) Future<void>
stopApiPolling() → void
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited
updateCart(BuildContext context, String cartId, AddToCartRequest request, ProductContentModel offerList, {bool isShowMsg = false}) → dynamic
updateDeliveryShippingMethod() Future<void>
updatePayment() → dynamic
updatePickupShippingMethod() → void
updatePromotion(BuildContext context, String cartDiscountId, String cartId) → dynamic
updateQuantity(BuildContext context, String quantity, String cartId, String productId) Future<bool>
updateSellThruOrder(CartModel model) Future<void>
uploadDoc({required File file, required dynamic onUpload(BankReceiptUploadModel)}) Future

Operators

operator ==(Object other) bool
The equality operator.
inherited