onInit method
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
Implementation
@override
void onInit() async {
super.onInit();
paymentStatusApiCall =
int.parse(storage.read("payment_status_api_call") ?? "10");
paymentScreenTime = int.parse(storage.read("payment_screen_time") ?? "600");
paymentStatusName = storage.read("paymentStatusName") ?? "SUCCESS";
paymentStatusList = storage.read("paymentStatusList") ?? "FAILURE,EXPIRED";
dio.options = BaseOptions(
receiveTimeout: const Duration(
seconds: Constants.defaultTimeout,
),
connectTimeout: const Duration(
seconds: Constants.defaultTimeout,
),
baseUrl: ApiConstant.baseUrl,
followRedirects: true,
);
dio.options.headers["Authorization"] =
"Bearer ${SecureStorageService.readSecureData(
SecureStorageService.accessToken,
)}";
printLogs(dio);
}