WalletController class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • WalletController
Implemented types

Constructors

WalletController()

Properties

actionType ↔ RxString
getter/setter pair
couponResponse Map<String, Object?>
getter/setter pair
couponTransactionId String
getter/setter pair
currentPage ↔ RxInt
getter/setter pair
currentWalletBalance ↔ RxDouble
getter/setter pair
currentWalletCurrency ↔ RxString
getter/setter pair
customerID ↔ RxString
getter/setter pair
denominationController TextEditingController
getter/setter pair
denominationList ↔ RxList<Content>
getter/setter pair
dio → Dio
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isDiscardPayment bool
getter/setter pair
isLoadingMore ↔ RxBool
getter/setter pair
isPaymentSelected ↔ RxBool
getter/setter pair
isPaymentSelectName ↔ RxString
getter/setter pair
isResponseRecieved ↔ RxBool
getter/setter pair
listeners int
no setterinherited
localization Localization
final
maxAmt ↔ RxDouble
getter/setter pair
minAmt ↔ RxDouble
getter/setter pair
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
paymentBankDataList ↔ RxList<PaymentData>
getter/setter pair
paymentCreateTransactionId ↔ RxString
getter/setter pair
paymentDataList List<PaymentData>
getter/setter pair
paymentModeList ↔ RxList<PaymentData>
getter/setter pair
paymentModes List<PaymentData>
getter/setter pair
paymentmodestatus int
getter/setter pair
paymentModeValidateList ↔ RxList<Mode>
getter/setter pair
paymentScreenTime int
getter/setter pair
paymentScreenType ↔ RxString
getter/setter pair
paymentStatus ↔ RxString
getter/setter pair
paymentStatusApiCall int
getter/setter pair
paymentStatusList String
getter/setter pair
paymentStatusName String
getter/setter pair
paymentTransactionId ↔ RxString
getter/setter pair
paymentTransactionList ↔ RxList<Content>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedAmount ↔ RxDouble
getter/setter pair
selectedPaymentMethod ↔ Rx<PaymentData>
getter/setter pair
storage → GetStorage
final
submitResponse Map<String, Object?>
getter/setter pair
targetSourceEmailID String
getter/setter pair
targetSourceEntityId String
getter/setter pair
targetSourceFirstName String
getter/setter pair
targetSourceLastName String
getter/setter pair
targetSourcePhone String
getter/setter pair
totalTransaction int
getter/setter pair
transactionId String
getter/setter pair
transactionList ↔ RxList<Content>
getter/setter pair

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
callCreateCouponApi(double amount) Future<void>
callPaymentTransactionCreateApi(String couponTransactionId, String type, String amount) Future<void>
callPaymentTransactionStatusApi(String transaction, bool externalCheckRequried, bool isDiscard, {bool isClickBack = false, bool isClickPaymentContinue = false, bool isFromDeepLink = false}) Future<void>
callSubmitCouponApi(String paymentGateWayTransactionId, String amount) Future<void>
checkAppAvailability() Future<bool>
checkDataOnLoad(String amount, {bool isDeepLink = false}) Future<void>
disableCancelButton(String completedStatus) bool
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
getDenominationData() → dynamic
getPaymentModeList() → void
getPaymentModes() → dynamic
getWalletBalance() → dynamic
getWalletTransactions({int page = 1}) → dynamic
handleApiResponse(PaymentStatusResponseModel? model) → void
handleBackApiResponse(PaymentStatusResponseModel? model, {bool isClickPaymentContinue = false, bool isClickBack = false}) → void
launchPaymentGateway(String url, String transactionid, String amount) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
printLogs(Dio dio) → dynamic
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
refreshOrderPending(BuildContext context, {required String entityId, required String couponTransactionId, required Function onStatusChange}) → dynamic
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
showDialogForPaymentAlert() Future<void>
Payment Dialog Alert
showPaymentFailedAlert() Future<void>
startApiPolling(String transaction) Future<void>
stopApiPolling() → void
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited