onInit method
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
Implementation
@override
void onInit() async {
super.onInit();
paymentStatusApiCall =
int.parse(storage.read("payment_status_api_call") ?? "10");
paymentScreenTime = int.parse(storage.read("payment_screen_time") ?? "600");
paymentStatusName = storage.read("paymentStatusName") ?? "SUCCESS";
paymentStatusList = storage.read("paymentStatusList") ?? "FAILURE,EXPIRED";
targetSourceEntityId = storage.read("targetSourceEntityId") ?? "9999";
targetSourceFirstName =
storage.read("targetSourceFirstName") ?? "Head Office";
targetSourceLastName = storage.read("targetSourceLastName") ?? "";
targetSourcePhone = storage.read("targetSourcePhone") ?? "12818513";
targetSourceEmailID =
storage.read("targetSourceEmailID") ?? "savoeun@cellcard.com.kh";
minAmt.value =
double.tryParse(storage.read("couponMinAmount") ?? "10.0") ?? 10.0;
maxAmt.value =
double.tryParse(storage.read("couponMaxAmount") ?? "10000.0") ??
10000.0;
dio.options = BaseOptions(
receiveTimeout: const Duration(
seconds: Constants.defaultTimeout,
),
connectTimeout: const Duration(
seconds: Constants.defaultTimeout,
),
followRedirects: true,
);
dio.options.headers["x-request-txn-id"] = UDID.getUDID();
dio.options.headers["x-trace-id"] = UDID.uDIDTraceId;
printLogs(dio);
}