CreditNote class
- Annotations
-
- @JsonSerializable.new()
Constructors
- CreditNote({SearchParam? searchParam, Bulk? bulk, FileUpload? fileUpload, Bulk? eload})
-
CreditNote.fromJson(Map<
String, dynamic> json) -
factory
Properties
- bulk ↔ Bulk?
-
getter/setter pair
- eload ↔ Bulk?
-
getter/setter pair
- fileUpload ↔ FileUpload?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchParam ↔ SearchParam?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited