Denomination class
- Annotations
-
- @JsonSerializable.new()
Constructors
- Denomination({String? value, String? currency, String? pogId, String? offerId, bool isSelected = false})
-
Denomination.fromJson(Map<
String, dynamic> json) -
factory
Properties
- currency ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSelected ↔ bool
-
getter/setter pair
- offerId ↔ String?
-
getter/setter pair
- pogId ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited