QrCodeDetails class

Annotations
  • @JsonSerializable.new()

Constructors

QrCodeDetails({String? resourceLocation, String? qrCodeContent, String? qrId})
QrCodeDetails.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
qrCodeContent String?
getter/setter pair
qrId String?
getter/setter pair
resourceLocation String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited