Content class
- Annotations
-
- @JsonSerializable.new()
Constructors
- Content({Profile? profile, dynamic addressDetails, dynamic signatory, dynamic account, dynamic creditLimit, dynamic documents, dynamic storeLimit, dynamic assignment})
-
Content.fromJson(Map<
String, dynamic> json) -
factory
Properties
- account ↔ dynamic
-
getter/setter pair
- addressDetails ↔ dynamic
-
getter/setter pair
- assignment ↔ dynamic
-
getter/setter pair
- creditLimit ↔ dynamic
-
getter/setter pair
- documents ↔ dynamic
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- profile ↔ Profile?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signatory ↔ dynamic
-
getter/setter pair
- storeLimit ↔ dynamic
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited