SubmitStockOrderData class

Constructors

SubmitStockOrderData({String? id, String? orderId, String? saleOrderId, String? invoiceId, String? orderUpdationId, String? paymentTransactionId, String? cartId, String? saleType, String? transactionType, int? saleDate, SellerDetails? sellerDetails, BuyerDetails? buyerDetails, String? partnerId, dynamic promos, String? saleOrderTpe, List<OrderItem>? orderItems, dynamic attachments, dynamic approvalTaskIds, PriceInfo? wHT, PriceInfo? absoluteTotal, PriceInfo? totalDiscount, PriceInfo? totalTax, PriceInfo? totalPriceWithoutWHT, PriceInfo? totalWithoutTaxAndDiscount, dynamic totalPriceWithoutTaxAndWithDiscount, dynamic overAllTaxPercentage, PriceInfo? totalPriceWithoutTax, PriceInfo? totalWHT, PriceInfo? totalPaymentCollected, PriceInfo? orderTotal, PriceInfo? grandTotal, dynamic remarks, dynamic poReferenceNo, PriceInfo? totalNetPrice, PriceInfo? overallSaleTax, dynamic taxClassification, dynamic taxClassificationName, double? withHeldTaxPercentage, double? salesTaxPercentage, dynamic netPriceWithOutTaxAndDiscountWithOutTax, PriceInfo? totalDiscountPercentage, PriceInfo? totalNetExcludedWithHeldTax, PriceInfo? totalVATableSalesVATAmount, PriceInfo? totalNetTaxVATableSalesDiscount, PriceInfo? totalConversionRate, PriceInfo? totalNetTaxVATExemptSalesDiscount, PriceInfo? totalNetTaxZeroRatedSalesDiscount, PriceInfo? totalZeroRatedSale, PriceInfo? totalVATExemptSale, PriceInfo? totalFixed, dynamic saleTransactionId, dynamic totalInitialPaymentCollected, dynamic promoCode, String? billingOrShippingAddressId, PriceInfo? overAllTax, BuyerDetailInfo? buyerDetailInfo, dynamic sellerDetailInfo, List<ModeOfPayment>? modeOfPaymentList, List<HeaderDetails>? headerDetailsList, dynamic assetDeliveryDetails, dynamic deliveryOrderId, dynamic externalInvoiceId, String? subInvoiceId, PriceInfo? totalCommission, PriceInfo? totalNetCommission, double? exchangeRate, dynamic whtPercentage, String? whtBearer, String? invoiceDocType, PriceInfo? totalCommissionWithOutGrossUp, PriceInfo? totalNetPriceInLocalCurrency, PriceInfo? grandTotalInLocalCurrency, ShippingMethod? shippingMethod, dynamic deliveryType, String? deliveryOption, PriceInfo? absoluteTotalInLocalCurrency, PriceInfo? totalPriceWithoutWHTInLocalCurrency, PriceInfo? totalDiscountPercentageInLocalCurrency, PriceInfo? totalDiscountInLocalCurrency, PriceInfo? totalCommissionInLocalCurrency, PriceInfo? totalNetCommissionInLocalCurrency, PriceInfo? totalCommissionWithOutGrossUpInLocalCurrency, PriceInfo? deliveryCharge, PriceInfo? deliveryChargeInLocalCurrency, PriceInfo? totalWHTInLocalCurrency, dynamic deliveryChargeWithOutTax, PriceInfo? wht})
SubmitStockOrderData.fromJson(Map<String, dynamic> json)

Properties

absoluteTotal PriceInfo?
getter/setter pair
absoluteTotalInLocalCurrency PriceInfo?
getter/setter pair
approvalTaskIds ↔ dynamic
getter/setter pair
assetDeliveryDetails ↔ dynamic
getter/setter pair
attachments ↔ dynamic
getter/setter pair
billingOrShippingAddressId String?
getter/setter pair
buyerDetailInfo BuyerDetailInfo?
getter/setter pair
buyerDetails BuyerDetails?
getter/setter pair
cartId String?
getter/setter pair
deliveryCharge PriceInfo?
getter/setter pair
deliveryChargeInLocalCurrency PriceInfo?
getter/setter pair
deliveryChargeWithOutTax ↔ dynamic
getter/setter pair
deliveryOption String?
getter/setter pair
deliveryOrderId ↔ dynamic
getter/setter pair
deliveryType ↔ dynamic
getter/setter pair
exchangeRate double?
getter/setter pair
externalInvoiceId ↔ dynamic
getter/setter pair
grandTotal PriceInfo?
getter/setter pair
grandTotalInLocalCurrency PriceInfo?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
headerDetailsList List<HeaderDetails>?
getter/setter pair
id String?
getter/setter pair
invoiceDocType String?
getter/setter pair
invoiceId String?
getter/setter pair
modeOfPaymentList List<ModeOfPayment>?
getter/setter pair
netPriceWithOutTaxAndDiscountWithOutTax ↔ dynamic
getter/setter pair
orderId String?
getter/setter pair
orderItems List<OrderItem>?
getter/setter pair
orderTotal PriceInfo?
getter/setter pair
orderUpdationId String?
getter/setter pair
overallSaleTax PriceInfo?
getter/setter pair
overAllTax PriceInfo?
getter/setter pair
overAllTaxPercentage ↔ dynamic
getter/setter pair
partnerId String?
getter/setter pair
paymentTransactionId String?
getter/setter pair
poReferenceNo ↔ dynamic
getter/setter pair
promoCode ↔ dynamic
getter/setter pair
promos ↔ dynamic
getter/setter pair
remarks ↔ dynamic
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saleDate int?
getter/setter pair
saleOrderId String?
getter/setter pair
saleOrderTpe String?
getter/setter pair
salesTaxPercentage double?
getter/setter pair
saleTransactionId ↔ dynamic
getter/setter pair
saleType String?
getter/setter pair
sellerDetailInfo ↔ dynamic
getter/setter pair
sellerDetails SellerDetails?
getter/setter pair
shippingMethod ShippingMethod?
getter/setter pair
subInvoiceId String?
getter/setter pair
taxClassification ↔ dynamic
getter/setter pair
taxClassificationName ↔ dynamic
getter/setter pair
totalCommission PriceInfo?
getter/setter pair
totalCommissionInLocalCurrency PriceInfo?
getter/setter pair
totalCommissionWithOutGrossUp PriceInfo?
getter/setter pair
totalCommissionWithOutGrossUpInLocalCurrency PriceInfo?
getter/setter pair
totalConversionRate PriceInfo?
getter/setter pair
totalDiscount PriceInfo?
getter/setter pair
totalDiscountInLocalCurrency PriceInfo?
getter/setter pair
totalDiscountPercentage PriceInfo?
getter/setter pair
totalDiscountPercentageInLocalCurrency PriceInfo?
getter/setter pair
totalFixed PriceInfo?
getter/setter pair
totalInitialPaymentCollected ↔ dynamic
getter/setter pair
totalNetCommission PriceInfo?
getter/setter pair
totalNetCommissionInLocalCurrency PriceInfo?
getter/setter pair
totalNetExcludedWithHeldTax PriceInfo?
getter/setter pair
totalNetPrice PriceInfo?
getter/setter pair
totalNetPriceInLocalCurrency PriceInfo?
getter/setter pair
totalNetTaxVATableSalesDiscount PriceInfo?
getter/setter pair
totalNetTaxVATExemptSalesDiscount PriceInfo?
getter/setter pair
totalNetTaxZeroRatedSalesDiscount PriceInfo?
getter/setter pair
totalPaymentCollected PriceInfo?
getter/setter pair
totalPriceWithoutTax PriceInfo?
getter/setter pair
totalPriceWithoutTaxAndWithDiscount ↔ dynamic
getter/setter pair
totalPriceWithoutWHT PriceInfo?
getter/setter pair
totalPriceWithoutWHTInLocalCurrency PriceInfo?
getter/setter pair
totalTax PriceInfo?
getter/setter pair
totalVATableSalesVATAmount PriceInfo?
getter/setter pair
totalVATExemptSale PriceInfo?
getter/setter pair
totalWHT PriceInfo?
getter/setter pair
totalWHTInLocalCurrency PriceInfo?
getter/setter pair
totalWithoutTaxAndDiscount PriceInfo?
getter/setter pair
totalZeroRatedSale PriceInfo?
getter/setter pair
transactionType String?
getter/setter pair
wHT PriceInfo?
getter/setter pair
wht PriceInfo?
getter/setter pair
whtBearer String?
getter/setter pair
whtPercentage ↔ dynamic
getter/setter pair
withHeldTaxPercentage double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited