formatEditUpdate method

  1. @override
TextEditingValue formatEditUpdate(
  1. TextEditingValue oldValue,
  2. TextEditingValue newValue
)
override

Called when text is being typed or cut/copy/pasted in the EditableText.

You can override the resulting text based on the previous text value and the incoming new text value.

When formatters are chained, oldValue reflects the initial value of TextEditingValue at the beginning of the chain.

Implementation

@override
TextEditingValue formatEditUpdate(
    TextEditingValue oldValue,
    TextEditingValue newValue,
    ) {
  final text = newValue.text;

  // Allow empty input
  if (text.isEmpty) {
    return newValue;
  }

  // Disallow leading zero unless followed by '.'
  if (text.startsWith('0') && text.length > 1 && text[1] != '.') {
    return oldValue;
  }

  // Allow digits and optional decimal
  final regExp = RegExp(r'^\d*\.?\d*$');
  if (!regExp.hasMatch(text)) {
    return oldValue;
  }

  // If there's a decimal, enforce decimal range
  if (text.contains('.')) {
    final parts = text.split('.');
    if (parts.length > 2) return oldValue; // Multiple dots
    if (parts[1].length > decimalRange) return oldValue;
  }

  return newValue;
}